Module cache

A set of caches which serve to speed up access to data, and in the case of websites, enable access to different versions of a website to work in a standard browser. Without a way to map the ‘host’ part of a URL to a VERSION and HISTORY-ADDRESS, it would not be possible for a dweb server to know which version of a website an HttpRequest was related to.

TODO: consider persisting the caches (do any feature serde?)

Modules

directory
directory_with_name
Caching of dweb URLs and DWEB-NAMEs is used to both reduce network access for repeated requests and to provide a local DNS based on DWEB-NAME, where each DWEB-NAME corresponds do a DirectoryTree history (History).
directory_with_port
Cache of active per-port directory/website listeners.
file
spawn