pub struct ApiControl {
pub tries: u32,
pub upload_file_by_file: bool,
pub ignore_pointers: Option<bool>,
pub show_dweb_costs: ShowCost,
pub max_fee_per_gas: Option<u128>,
}Expand description
Control how dweb uses and reports on selected Autonomi APIs
This allows use of the API to be made more reliable by enabling numbers of retries for some operations, how uploads are conducted and so on.
Fields
tries: u32Control number of tries on selected Autonomi calls (0 for unlimited)
upload_file_by_file: boolDo upload of directories one file at a time. Without this a retry will start from scratch.
ignore_pointers: Option<bool>Control dweb APIs use of pointers.
For selected APIs, if ignore_pointer is Some(true) the API will find the most recentry entry (head) of a graph by following the graph from the Pointer target to the end. When it is Some(false) the pointer is assumed to be up-to-date and point to the most recent graph entry.
When None, behaviour depends on the API, but most will trust that the pointer is up-to-date and points to the most recent entry of of a graph.
Can be used to investigate behaviour such as Pointers not updating on the public network.
show_dweb_costs: ShowCostShow the cost of dweb API calls after each call in tokens, gas, both or none
max_fee_per_gas: Option<u128>Optional maximum fee in Gwei (units of 0.000000001 ETH), to pay for a transaction on the Arbitrum network.