debug_print_graph_entry

Function debug_print_graph_entry 

pub fn debug_print_graph_entry(
    intro: &str,
    graph_entry: &GraphEntry,
    main_owner: Option<MainSecretKey>,
)
Print a summary for a GraphEntry. If main_owner.is_some() the output will use this to show the addresses of parent and descendents instead of their PublicKeys.