Module history

Module history 

Structs

History
A history of versions of a type implementing the Trove trait. This can be used to create and access versions of a file, a collection of files such as a directory, or all the files and settings that make up a website, and so on. TODO provide a way to initialise a history from an Autonomi Register pointer and graph
HistoryAddress
A History is addressed at a HistoryAddress which is derived from the owner’s PublicKey and a name. This means a single owner key can manage multiple histories.
TroveVersion
The state of a Trove struct at a given version with optional cache of its data

Constants

HISTORY_VALUE_SIZE
The size of a history value: 32 bytes

Traits

Trove
gives access to every version of the struct that has ever been stored on Autonomi.

Functions

get_and_verify_pointer
history_value_from_bytes
Create a new HistoryValue from bytes, make sure the bytes are not longer than HISTORY_VALUE_SIZE
pointer_address_from_history_address

Type Aliases

HistoryValue
The value of a history: a 32 bytes array (same as GraphContent)