Module storage

Module storage 

Enums

DwebType
Network data types for dweb APIs

Functions

directory_upload_private
Upload a directory and retun the PrivateArchive and total cost
directory_upload_public
Upload a directory and retun the PublicArchive and total cost
publish_directory
Upload a directory tree to Autonomi and store the PrivateArchive Returns the network address of the PrivateArchive (which can be used to initialise a Tree).
publish_files_private
Upload the tree of files with the option to include a dweb settings file. Each file’s datamap chunk is stored in the PrivateArchive but not on the network. Does not store the PrivateArchive.
publish_files_public
Upload the tree of files with the option to include a dweb settings file
publish_or_update_files
Publish a history entry, creating the history if no name is provided
report_content_published_or_updated