DwebClient is a wrapper for the Autonomi::client::client
Provides a simple way to connect and fund a client for interaction with the Autonomi peer-to-peer storage network.
Structs
- ApiControl
- Control how dweb uses and reports on selected Autonomi APIs
- Dweb
Client - A wrapper for autonomi::Client which simplifies use of dweb APIs TODO support separate data creation/owner and wallet keys