Structs
- History
- A history of versions of a type implementing the Trove trait. This can be used to create and access versions of a file, a collection of files such as a directory, or all the files and settings that make up a website, and so on. TODO provide a way to initialise a history from an Autonomi Register pointer and graph
- History
Address - A History is addressed at a
HistoryAddresswhich is derived from the owner’sPublicKeyand a name. This means a single owner key can manage multiple histories. - Trove
Version - The state of a Trove struct at a given version with optional cache of its data
Constants
- HISTORY_
VALUE_ SIZE - The size of a history value: 32 bytes
Traits
- Trove
- gives access to every version of the struct that has ever been stored on Autonomi.
Functions
- get_
and_ verify_ pointer - history_
value_ from_ bytes - Create a new
HistoryValuefrom bytes, make sure the bytes are not longer thanHISTORY_VALUE_SIZE - pointer_
address_ from_ history_ address
Type Aliases
- History
Value - The value of a history: a 32 bytes array (same as
GraphContent)