Enums
- Dweb
Type - Network data types for dweb APIs
Functions
- directory_
upload_ private - Upload a directory and retun the PrivateArchive and total cost
- directory_
upload_ public - Upload a directory and retun the PublicArchive and total cost
- publish_
directory - Upload a directory tree to Autonomi and store the PrivateArchive Returns the network address of the PrivateArchive (which can be used to initialise a Tree).
- publish_
files_ private - Upload the tree of files with the option to include a dweb settings file. Each file’s datamap chunk is stored in the PrivateArchive but not on the network. Does not store the PrivateArchive.
- publish_
files_ public - Upload the tree of files with the option to include a dweb settings file
- publish_
or_ update_ files - Publish a history entry, creating the history if no name is provided
- report_
content_ published_ or_ updated